==> ogre-14.4.1-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/group__deprecated.js <==
var group__deprecated =
[
    [ "Ogre::deque< T >", "struct_ogre_1_1deque.html", [
      [ "type", "struct_ogre_1_1deque.html#a8ef708c605cdfef7dde4d3aa3ed8ea99", null ],
      [ "iterator", "struct_ogre_1_1deque.html#a968f95e0bf20d851997141c3f9a7a5ee", null ],
      [ "const_iterator", "struct_ogre_1_1deque.html#aa8b793ad596efea014e06a5782dcbf38", null ]
    ] ],
    [ "Ogre::list< T >", "struct_ogre_1_1list.html", [
      [ "type", "struct_ogre_1_1list.html#af5f494d11293e3207bf6d71dfd559a3b", null ],
      [ "iterator", "struct_ogre_1_1list.html#a152e17cd121940590cf3461a0543675d", null ],
      [ "const_iterator", "struct_ogre_1_1list.html#aa8e3416ed3f67da65d3ee10dcffdedb1", null ]
    ] ],
    [ "Ogre::map< K, V, P >", "struct_ogre_1_1map.html", [
      [ "type", "struct_ogre_1_1map.html#a32ee61e7fed8a58db9379ed59cc20d33", null ],
      [ "iterator", "struct_ogre_1_1map.html#adb0a925ad566db128615680dfea42e40", null ],
      [ "const_iterator", "struct_ogre_1_1map.html#a3049735a71ab36d63b66cb58c3103e1e", null ]
    ] ],
    [ "Ogre::multimap< K, V, P >", "struct_ogre_1_1multimap.html", [
      [ "type", "struct_ogre_1_1multimap.html#aaed3d4a16033f6f15eca2ceb551ad258", null ],
      [ "iterator", "struct_ogre_1_1multimap.html#a8c990e7c7fb8b462517e0adbf7cfe42a", null ],
      [ "const_iterator", "struct_ogre_1_1multimap.html#a7118ca2ad7e28486e087ce0f895f063d", null ]
    ] ],
    [ "Ogre::set< T, P >", "struct_ogre_1_1set.html", [
      [ "type", "struct_ogre_1_1set.html#ab212178827fff17754a2926d84f8f4dc", null ],
      [ "iterator", "struct_ogre_1_1set.html#a374a2af2ae9247f9dcb671dd58a05832", null ],
      [ "const_iterator", "struct_ogre_1_1set.html#af2fca6a352e8f4776983ebc9e1278ce5", null ]
    ] ],
    [ "Ogre::SPFMDeleteT", "struct_ogre_1_1_s_p_f_m_delete_t.html", [
      [ "operator()", "struct_ogre_1_1_s_p_f_m_delete_t.html#a86fde4968ee43dc5f05fee98079c06c1", null ]
    ] ],
    [ "Ogre::SPFMNone", "struct_ogre_1_1_s_p_f_m_none.html", [
      [ "operator()", "struct_ogre_1_1_s_p_f_m_none.html#a8380b41af32cb73f7d16eb4e6f29beff", null ]
    ] ],
    [ "Ogre::vector< T >", "struct_ogre_1_1vector.html", [
      [ "type", "struct_ogre_1_1vector.html#a433d2c685114e4935ed8b8126540f874", null ],
      [ "iterator", "struct_ogre_1_1vector.html#a65821ceab89a9c9e96821410110921fd", null ],
      [ "const_iterator", "struct_ogre_1_1vector.html#adc8cc0eab4ac5869d66579b33ae23989", null ]
    ] ],
    [ "OGRE_HashMap", "group__deprecated.html#gaae66141905ddac9ea7b0a562d2dab69d", null ],
    [ "OGRE_HashMultiMap", "group__deprecated.html#ga669d1b4211776fa2d7fdbf0e17ecd304", null ],
    [ "OGRE_HashSet", "group__deprecated.html#gacff21880202e98896528710bed75fce4", null ],
    [ "OGRE_HashMultiSet", "group__deprecated.html#ga973d69768eae85a9282eb97ee0d3bced", null ],
    [ "Ogre::AtomicScalar", "group__deprecated.html#ga64d5737d0d756e87a82f40b70ce377f9", null ],
    [ "Ogre::QuadMaterialMap", "group__deprecated.html#ga30d973e2d8b22c92d4b09f78c0531508", null ],
    [ "Ogre::SceneTypeMask", "group__deprecated.html#gaa4b6dbd7bf722582a21fcc25d25f73ed", null ],
    [ "Ogre::SceneType", "group__deprecated.html#ga7383602bd480d43b80c626969b9af914", [
      [ "Ogre::ST_GENERIC", "group__deprecated.html#gga7383602bd480d43b80c626969b9af914a0af8f844019e52fe112e9a946a919fcd", null ],
      [ "Ogre::ST_EXTERIOR_CLOSE", "group__deprecated.html#gga7383602bd480d43b80c626969b9af914ae83ae1c9a6e4816184441db4a140e70a", null ],
      [ "Ogre::ST_EXTERIOR_FAR", "group__deprecated.html#gga7383602bd480d43b80c626969b9af914a8bf5864d5ab311e0512ed153c95f1d13", null ],
      [ "Ogre::ST_EXTERIOR_REAL_FAR", "group__deprecated.html#gga7383602bd480d43b80c626969b9af914a7eecd7057b3487616075032560582ec1", null ],
      [ "Ogre::ST_INTERIOR", "group__deprecated.html#gga7383602bd480d43b80c626969b9af914a93f2170ad3a8132f29264dc3642a2dcf", null ]
    ] ],
    [ "Ogre::SPFM_NONE", "group__deprecated.html#ga7eed296b598179beccca6458853544f2", null ],
    [ "Ogre::SPFM_DELETE_T", "group__deprecated.html#gaf6f97a6839d09383771cbe638a56f256", null ]
];

==> ogre-14.5.0-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/group__deprecated.js <==
var group__deprecated =
[
    [ "Ogre::deque&lt; T &gt;", "struct_ogre_1_1deque.html", [
      [ "type", "struct_ogre_1_1deque.html#a8ef708c605cdfef7dde4d3aa3ed8ea99", null ],
      [ "iterator", "struct_ogre_1_1deque.html#a968f95e0bf20d851997141c3f9a7a5ee", null ],
      [ "const_iterator", "struct_ogre_1_1deque.html#aa8b793ad596efea014e06a5782dcbf38", null ]
    ] ],
    [ "Ogre::list&lt; T &gt;", "struct_ogre_1_1list.html", [
      [ "type", "struct_ogre_1_1list.html#af5f494d11293e3207bf6d71dfd559a3b", null ],
      [ "iterator", "struct_ogre_1_1list.html#a152e17cd121940590cf3461a0543675d", null ],
      [ "const_iterator", "struct_ogre_1_1list.html#aa8e3416ed3f67da65d3ee10dcffdedb1", null ]
    ] ],
    [ "Ogre::map&lt; K, V, P &gt;", "struct_ogre_1_1map.html", [
      [ "type", "struct_ogre_1_1map.html#a32ee61e7fed8a58db9379ed59cc20d33", null ],
      [ "iterator", "struct_ogre_1_1map.html#adb0a925ad566db128615680dfea42e40", null ],
      [ "const_iterator", "struct_ogre_1_1map.html#a3049735a71ab36d63b66cb58c3103e1e", null ]
    ] ],
    [ "Ogre::multimap&lt; K, V, P &gt;", "struct_ogre_1_1multimap.html", [
      [ "type", "struct_ogre_1_1multimap.html#aaed3d4a16033f6f15eca2ceb551ad258", null ],
      [ "iterator", "struct_ogre_1_1multimap.html#a8c990e7c7fb8b462517e0adbf7cfe42a", null ],
      [ "const_iterator", "struct_ogre_1_1multimap.html#a7118ca2ad7e28486e087ce0f895f063d", null ]
    ] ],
    [ "Ogre::set&lt; T, P &gt;", "struct_ogre_1_1set.html", [
      [ "type", "struct_ogre_1_1set.html#ab212178827fff17754a2926d84f8f4dc", null ],
      [ "iterator", "struct_ogre_1_1set.html#a374a2af2ae9247f9dcb671dd58a05832", null ],
      [ "const_iterator", "struct_ogre_1_1set.html#af2fca6a352e8f4776983ebc9e1278ce5", null ]
    ] ],
    [ "Ogre::SPFMDeleteT", "struct_ogre_1_1_s_p_f_m_delete_t.html", [
      [ "operator()", "struct_ogre_1_1_s_p_f_m_delete_t.html#a86fde4968ee43dc5f05fee98079c06c1", null ]
    ] ],
    [ "Ogre::SPFMNone", "struct_ogre_1_1_s_p_f_m_none.html", [
      [ "operator()", "struct_ogre_1_1_s_p_f_m_none.html#a8380b41af32cb73f7d16eb4e6f29beff", null ]
    ] ],
    [ "Ogre::vector&lt; T &gt;", "struct_ogre_1_1vector.html", [
      [ "type", "struct_ogre_1_1vector.html#a433d2c685114e4935ed8b8126540f874", null ],
      [ "iterator", "struct_ogre_1_1vector.html#a65821ceab89a9c9e96821410110921fd", null ],
      [ "const_iterator", "struct_ogre_1_1vector.html#adc8cc0eab4ac5869d66579b33ae23989", null ]
    ] ],
    [ "OGRE_HashMap", "group__deprecated.html#gaae66141905ddac9ea7b0a562d2dab69d", null ],
    [ "OGRE_HashMultiMap", "group__deprecated.html#ga669d1b4211776fa2d7fdbf0e17ecd304", null ],
    [ "OGRE_HashSet", "group__deprecated.html#gacff21880202e98896528710bed75fce4", null ],
    [ "OGRE_HashMultiSet", "group__deprecated.html#ga973d69768eae85a9282eb97ee0d3bced", null ],
    [ "Ogre::AtomicScalar", "group__deprecated.html#ga64d5737d0d756e87a82f40b70ce377f9", null ],
    [ "Ogre::QuadMaterialMap", "group__deprecated.html#ga30d973e2d8b22c92d4b09f78c0531508", null ],
    [ "Ogre::SceneTypeMask", "group__deprecated.html#gaa4b6dbd7bf722582a21fcc25d25f73ed", null ],
    [ "Ogre::SceneType", "group__deprecated.html#ga7383602bd480d43b80c626969b9af914", [
      [ "Ogre::ST_GENERIC", "group__deprecated.html#gga7383602bd480d43b80c626969b9af914a0af8f844019e52fe112e9a946a919fcd", null ],
      [ "Ogre::ST_EXTERIOR_CLOSE", "group__deprecated.html#gga7383602bd480d43b80c626969b9af914ae83ae1c9a6e4816184441db4a140e70a", null ],
      [ "Ogre::ST_EXTERIOR_FAR", "group__deprecated.html#gga7383602bd480d43b80c626969b9af914a8bf5864d5ab311e0512ed153c95f1d13", null ],
      [ "Ogre::ST_EXTERIOR_REAL_FAR", "group__deprecated.html#gga7383602bd480d43b80c626969b9af914a7eecd7057b3487616075032560582ec1", null ],
      [ "Ogre::ST_INTERIOR", "group__deprecated.html#gga7383602bd480d43b80c626969b9af914a93f2170ad3a8132f29264dc3642a2dcf", null ]
    ] ],
    [ "Ogre::SPFM_NONE", "group__deprecated.html#ga7eed296b598179beccca6458853544f2", null ],
    [ "Ogre::SPFM_DELETE_T", "group__deprecated.html#gaf6f97a6839d09383771cbe638a56f256", null ]
];
